@@ -19,11 +19,6 @@ then
   exit 1
 fi
 
-if [ ! "$BASH_VERSION" ] ; then
-  find . -type f -name '*.html' -exec sed -i '' "s/URL/$1/g" {} +
-  find . -type f -name '*.xml' -exec sed -i '' "s/URL/$1/g" {} +
-else
-  find . -type f -name '*.html' -exec sed -i "s/URL/$1/g" {} +
-  find . -type f -name '*.xml' -exec sed -i "s/URL/$1/g" {} +
-fi
+find . -type f -name '*.html' -exec sed -i "s/URL/$1/g" {} +
+find . -type f -name '*.xml' -exec sed -i "s/URL/$1/g" {} +
 
